Miscellaneous resources — Scikit-HEP 0.0.1 documentation

# Miscellaneous resources

A collection of presentations, videos and publications on, or related to, the Scikit-HEP project.

## Presentations

- 23 Oct. 2017: DIANA/HEP project topical meeting (https://indico.cern.ch/event/664968/), CERN:
  - numpythia & pyjet - interfacing PYTHIA and FastJet with NumPy, Noel Dawe
- 11 Sep. 2017: project status report, DIANA/HEP project topical meeting (https://indico.cern.ch/event/650630/), CERN:
  - Scikit-HEP project status, Eduardo Rodrigues
- 6 April 2017: presentation of the project to the LHCb experiment, LHCb experiment Analysis & Software Week, CERN:
  - The Scikit-HEP project, Eduardo Rodrigues
- 27 Feb. 2017: first presentation of the project, DIANA/HEP project topical meeting (https://indico.cern.ch/event/596272/), CERN:
  - The Scikit-HEP project, Eduardo Rodrigues
  - Ostap concepts in Scikit-HEP, Vanya Belyaev
  - Rootpy and root_numpy concepts in Scikit-HEP, Noel Dawe